@@ -1,16 +1,23 @@
+import logging
 import os
 from abc import ABC, abstractmethod
 from collections import defaultdict
 from datetime import datetime
 from functools import wraps
 from pathlib import Path
-from typing import IO, Dict, FrozenSet, Generator, List, Optional, Union
+from typing import IO, Any, Dict, FrozenSet, Generator, List, Optional, Union
 
 import git
-from pydantic import BaseModel, parse_obj_as, validator
+from git import Repo
+from pydantic import BaseModel, ValidationError, parse_obj_as, validator
+from ruamel.yaml import YAMLError
 
 from gto.base import BaseManager, BaseRegistryState
 from gto.base import Commit as EnrichmentEvent
+from gto.commit_message_generator import (
+    generate_annotate_commit_message,
+    generate_remove_commit_message,
+)
 from gto.config import (
     CONFIG_FILE_NAME,
     RegistryConfig,
@@ -23,13 +30,17 @@ from gto.exceptions import (
     ArtifactExists,
     ArtifactNotFound,
     NoFile,
-    NoRepo,
     PathIsUsed,
     WrongArgs,
+    WrongArtifactsYaml,
 )
 from gto.ext import EnrichmentInfo, EnrichmentReader
+from gto.git_utils import RemoteRepoMixin, read_repo
+from gto.ui import echo
 from gto.utils import resolve_ref
 
+logger = logging.getLogger("gto")
+
 
 class Artifact(BaseModel):
     type: Optional[str] = None
@@ -37,6 +48,7 @@ class Artifact(BaseModel):
     virtual: bool = True
     labels: List[str] = []  # TODO: allow key:value labels
     description: str = ""
+    custom: Any = None
 
 
 State = Dict[str, Artifact]
@@ -111,10 +123,27 @@ class Index(BaseModel):
 
     @staticmethod
     def read_state(path_or_file: Union[str, IO]):
+        def read_yaml(stream: IO):
+            try:
+                return yaml.load(stream)
+            except YAMLError as e:
+                raise WrongArtifactsYaml() from e
+
+        # read contents of the yaml
         if isinstance(path_or_file, str):
-            with open(path_or_file, "r", encoding="utf8") as file:
-                return parse_obj_as(State, yaml.load(file))
-        state = parse_obj_as(State, yaml.load(path_or_file))
+            try:
+                with open(path_or_file, "r", encoding="utf8") as file:
+                    contents = read_yaml(file)
+            except FileNotFoundError as e:
+                raise NoFile("artifacts.yaml") from e
+        else:
+            contents = read_yaml(path_or_file)
+        # check yaml contents is a valid State
+        try:
+            state = parse_obj_as(State, contents)
+        except ValidationError as e:
+            raise WrongArtifactsYaml() from e
+        # validate that specific names conform to the naming convention
         for key in state:
             assert_name_is_valid(key)
         return state
@@ -127,12 +156,22 @@ class Index(BaseModel):
 
     @not_frozen
     def add(
-        self, name, type, path, must_exist, labels, description, update
+        self,
+        name,
+        type,
+        path,
+        must_exist,
+        allow_same_path,
+        labels,
+        description,
+        custom,
+        update,
     ) -> Artifact:
         if name in self and not update:
             raise ArtifactExists(name)
         if (
             path
+            and not allow_same_path
             and find_repeated_path(
                 path, [a.path for n, a in self.state.items() if n != name]
             )
@@ -148,6 +187,7 @@ class Index(BaseModel):
                 self.state[name].virtual = True
             self.state[name].labels = sorted(set(self.state[name].labels).union(labels))
             self.state[name].description = description or self.state[name].description
+            self.state[name].custom = custom or self.state[name].custom
         else:
             self.state[name] = Artifact(
                 type=type,
@@ -155,6 +195,7 @@ class Index(BaseModel):
                 virtual=not must_exist,
                 labels=labels,
                 description=description,
+                custom=custom,
             )
         self.state_is_valid(self.state)
         return self.state[name]
@@ -182,7 +223,19 @@ class BaseIndexManager(BaseModel, ABC):
     def get_history(self) -> Dict[str, Index]:
         raise NotImplementedError
 
-    def add(self, name, type, path, must_exist, labels, description, update):
+    def add(
+        self,
+        name,
+        type,
+        path,
+        must_exist,
+        allow_same_path,
+        labels,
+        description,
+        custom,
+        update,
+        stdout=False,
+    ):
         for arg in [name] + list(labels or []):
             assert_name_is_valid(arg)
         if type:
@@ -200,16 +253,22 @@ class BaseIndexManager(BaseModel, ABC):
             type=type,
             path=path,
             must_exist=must_exist,
+            allow_same_path=allow_same_path,
             labels=labels or [],
             description=description,
+            custom=custom,
             update=update,
         )
         self.update()
+        if stdout:
+            echo("Updated `artifacts.yaml`")
 
-    def remove(self, name):
+    def remove(self, name, stdout=False):
         index = self.get_index()
         index.remove(name)
         self.update()
+        if stdout:
+            echo("Updated `artifacts.yaml`")
 
 
 class FileIndexManager(BaseIndexManager):
@@ -238,27 +297,83 @@ class FileIndexManager(BaseIndexManager):
     def get_history(self) -> Dict[str, Index]:
         raise NotImplementedError("Not a git repo: history is not available")
 
+    def get_commit_index(self, **kwargs) -> Index:
+        raise NotImplementedError("Not a git repo: using revision is not available")
+
+    def artifact_centric_representation(self):
+        raise NotImplementedError("Not a git repo")
+
 
 ArtifactCommits = Dict[str, Artifact]
 ArtifactsCommits = Dict[str, ArtifactCommits]
 
 
-class RepoIndexManager(FileIndexManager):
+class RepoIndexManager(FileIndexManager, RemoteRepoMixin):
     repo: git.Repo
 
+    def __init__(self, repo, config):
+        super().__init__(repo=repo, config=config)
+
     @classmethod
-    def from_repo(cls, repo: Union[str, git.Repo], config: RegistryConfig = None):
-        if isinstance(repo, str):
-            try:
-                repo = git.Repo(repo, search_parent_directories=True)
-            except git.InvalidGitRepositoryError as e:
-                raise NoRepo(repo) from e
+    def from_local_repo(cls, repo: Union[str, git.Repo], config: RegistryConfig = None):
+        repo = read_repo(repo, search_parent_directories=True)
         if config is None:
             config = read_registry_config(
                 os.path.join(repo.working_dir, CONFIG_FILE_NAME)
             )
         return cls(repo=repo, config=config)
 
+    def add(
+        self,
+        name,
+        type,
+        path,
+        must_exist,
+        allow_same_path,
+        labels,
+        description,
+        custom,
+        update,
+        stdout=False,
+        commit=False,
+        commit_message=None,
+        push=False,
+    ):
+        return self._call_commit_push(
+            super().add,
+            commit=commit,
+            commit_message=commit_message
+            or generate_annotate_commit_message(name=name, type=type, path=path),
+            push=push,
+            stdout=stdout,
+            name=name,
+            type=type,
+            path=path,
+            must_exist=must_exist,
+            allow_same_path=allow_same_path,
+            labels=labels,
+            description=description,
+            custom=custom,
+            update=update,
+        )
+
+    def remove(
+        self,
+        name,
+        stdout=False,
+        commit=False,
+        commit_message=None,
+        push=False,
+    ):
+        return self._call_commit_push(
+            super().remove,
+            commit=commit,
+            commit_message=commit_message or generate_remove_commit_message(name=name),
+            push=push,
+            stdout=stdout,
+            name=name,
+        )
+
     def index_path(self):
         # TODO: config should be loaded from repo too
         return os.path.join(os.path.dirname(self.repo.git_dir), self.config.INDEX)
@@ -266,16 +381,25 @@ class RepoIndexManager(FileIndexManager):
     class Config:
         arbitrary_types_allowed = True
 
-    def get_commit_index(
-        self, ref: Union[str, git.Reference, None], allow_to_not_exist: bool = True
+    def get_commit_index(  # type: ignore # pylint: disable=arguments-differ
+        self,
+        ref: Union[str, git.Reference, None],
+        allow_to_not_exist: bool = True,
+        ignore_corrupted: bool = False,
     ) -> Optional[Index]:
         if not ref or isinstance(ref, str):
             ref = resolve_ref(self.repo, ref)
         if self.config.INDEX in ref.tree:
-            return Index.read(
-                (ref.tree / self.config.INDEX).data_stream,
-                frozen=True,
-            )
+            try:
+                return Index.read(
+                    (ref.tree / self.config.INDEX).data_stream,
+                    frozen=True,
+                )
+            except WrongArtifactsYaml as e:
+                logger.warning("Corrupted artifacts.yaml file in commit %s", ref)
+                if ignore_corrupted:
+                    return None
+                raise e
         if allow_to_not_exist:
             return None
         raise ValueError(f"No Index exists at {ref}")
@@ -307,11 +431,11 @@ class RepoIndexManager(FileIndexManager):
             raise ArtifactNotFound(name)
 
 
-class EnrichmentManager(BaseManager):
+class EnrichmentManager(BaseManager, RemoteRepoMixin):
     actions: FrozenSet[Action] = frozenset()
 
     @classmethod
-    def from_repo(cls, repo, config: RegistryConfig = None):
+    def from_local_repo(cls, repo: Union[str, Repo], config: RegistryConfig = None):
         if isinstance(repo, str):
             repo = git.Repo(repo, search_parent_directories=True)
         if config is None:
@@ -404,13 +528,6 @@ class EnrichmentManager(BaseManager):
         return state
 
 
-def init_index_manager(path):
-    try:
-        return RepoIndexManager.from_repo(path)
-    except NoRepo:
-        return FileIndexManager.from_path(path)
-
-
 class GTOInfo(EnrichmentInfo):
     source = "gto"
     artifact: Artifact
@@ -431,7 +548,8 @@ class GTOEnrichment(EnrichmentReader):
     def discover(  # pylint: disable=no-self-use
         self, repo, rev: Optional[Union[git.Reference, str]]
     ) -> Dict[str, GTOInfo]:
-        index = RepoIndexManager.from_repo(repo).get_commit_index(rev)
+        with RepoIndexManager.from_repo(repo) as index:
+            index = index.get_commit_index(rev)
         if index:
             return {
                 name: GTOInfo(artifact=artifact)
@@ -442,7 +560,8 @@ class GTOEnrichment(EnrichmentReader):
     def describe(  # pylint: disable=no-self-use
         self, repo, obj: str, rev: Optional[Union[git.Reference, str]]
     ) -> Optional[GTOInfo]:
-        index = RepoIndexManager.from_repo(repo).get_commit_index(rev)
+        with RepoIndexManager.from_repo(repo) as index:
+            index = index.get_commit_index(rev)
         if index and obj in index.state:
             return GTOInfo(artifact=index.state[obj])
         return None
