@@ -10,6 +10,7 @@ from rich.text import Text
 from gto.config import CONFIG
 
 console = Console()
+error_console = Console(stderr=True)
 
 _echo_func: Optional[Callable] = None
 
@@ -34,6 +35,12 @@ def cli_echo():
         yield
 
 
+@contextlib.contextmanager
+def stderr_echo():
+    with set_echo(error_console.print):
+        yield
+
+
 @contextlib.contextmanager
 def no_echo():
     with set_echo(None):
